GRINNING_FACE = "😀"
GRINNING_FACE_WITH_BIG_EYES = "😃"
GRINNING_FACE_WITH_SMILING_EYES = "😄"
BEAMING_FACE_WITH_SMILING_EYES = "😁"
GRINNING_SQUINTING_FACE = "😆"
GRINNING_FACE_WITH_SWEAT = "😅"
ROLLING_ON_THE_FLOOR_LAUGHING = "🤣"
FACE_WITH_TEARS_OF_JOY = "😂"
SLIGHTLY_SMILING_FACE = "🙂"
UPSIDEDOWN_FACE = "🙃"
WINKING_FACE = "😉"
SMILING_FACE_WITH_SMILING_EYES = "😊"
SMILING_FACE_WITH_HALO = "😇"
SMILING_FACE_WITH_HEARTS = "🥰"
SMILING_FACE_WITH_HEARTEYES = "😍"
STARSTRUCK = "🤩"
FACE_BLOWING_A_KISS = "😘"
KISSING_FACE = "😗"
SMILING_FACE = "☺"
KISSING_FACE_WITH_CLOSED_EYES = "😚"
KISSING_FACE_WITH_SMILING_EYES = "😙"
FACE_SAVORING_FOOD = "😋"
FACE_WITH_TONGUE = "😛"
WINKING_FACE_WITH_TONGUE = "😜"
ZANY_FACE = "🤪"
SQUINTING_FACE_WITH_TONGUE = "😝"
MONEYMOUTH_FACE = "🤑"
HUGGING_FACE = "🤗"
FACE_WITH_HAND_OVER_MOUTH = "🤭"
SHUSHING_FACE = "🤫"
THINKING_FACE = "🤔"
ZIPPERMOUTH_FACE = "🤐"
FACE_WITH_RAISED_EYEBROW = "🤨"
NEUTRAL_FACE = "😐"
EXPRESSIONLESS_FACE = "😑"
FACE_WITHOUT_MOUTH = "😶"
SMIRKING_FACE = "😏"
UNAMUSED_FACE = "😒"
FACE_WITH_ROLLING_EYES = "🙄"
GRIMACING_FACE = "😬"
LYING_FACE = "🤥"
RELIEVED_FACE = "😌"
PENSIVE_FACE = "😔"
SLEEPY_FACE = "😪"
DROOLING_FACE = "🤤"
SLEEPING_FACE = "😴"
FACE_WITH_MEDICAL_MASK = "😷"
FACE_WITH_THERMOMETER = "🤒"
FACE_WITH_HEADBANDAGE = "🤕"
NAUSEATED_FACE = "🤢"
FACE_VOMITING = "🤮"
SNEEZING_FACE = "🤧"
HOT_FACE = "🥵"
COLD_FACE = "🥶"
WOOZY_FACE = "🥴"
DIZZY_FACE = "😵"
EXPLODING_HEAD = "🤯"
COWBOY_HAT_FACE = "🤠"
PARTYING_FACE = "🥳"
SMILING_FACE_WITH_SUNGLASSES = "😎"
NERD_FACE = "🤓"
FACE_WITH_MONOCLE = "🧐"
CONFUSED_FACE = "😕"
WORRIED_FACE = "😟"
SLIGHTLY_FROWNING_FACE = "🙁"
FROWNING_FACE = "☹"
FACE_WITH_OPEN_MOUTH = "😮"
HUSHED_FACE = "😯"
ASTONISHED_FACE = "😲"
FLUSHED_FACE = "😳"
PLEADING_FACE = "🥺"
FROWNING_FACE_WITH_OPEN_MOUTH = "😦"
ANGUISHED_FACE = "😧"
FEARFUL_FACE = "😨"
ANXIOUS_FACE_WITH_SWEAT = "😰"
SAD_BUT_RELIEVED_FACE = "😥"
CRYING_FACE = "😢"
LOUDLY_CRYING_FACE = "😭"
FACE_SCREAMING_IN_FEAR = "😱"
CONFOUNDED_FACE = "😖"
PERSEVERING_FACE = "😣"
DISAPPOINTED_FACE = "😞"
DOWNCAST_FACE_WITH_SWEAT = "😓"
WEARY_FACE = "😩"
TIRED_FACE = "😫"
YAWNING_FACE = "🥱"
FACE_WITH_STEAM_FROM_NOSE = "😤"
POUTING_FACE = "😡"
ANGRY_FACE = "😠"
FACE_WITH_SYMBOLS_ON_MOUTH = "🤬"
SMILING_FACE_WITH_HORNS = "😈"
ANGRY_FACE_WITH_HORNS = "👿"
SKULL = "💀"
SKULL_AND_CROSSBONES = "☠"
PILE_OF_POO = "💩"
CLOWN_FACE = "🤡"
OGRE = "👹"
GOBLIN = "👺"
GHOST = "👻"
ALIEN = "👽"
ALIEN_MONSTER = "👾"
ROBOT = "🤖"
GRINNING_CAT = "😺"
GRINNING_CAT_WITH_SMILING_EYES = "😸"
CAT_WITH_TEARS_OF_JOY = "😹"
SMILING_CAT_WITH_HEARTEYES = "😻"
CAT_WITH_WRY_SMILE = "😼"
KISSING_CAT = "😽"
WEARY_CAT = "🙀"
CRYING_CAT = "😿"
POUTING_CAT = "😾"
SEENOEVIL_MONKEY = "🙈"
HEARNOEVIL_MONKEY = "🙉"
SPEAKNOEVIL_MONKEY = "🙊"
KISS_MARK = "💋"
LOVE_LETTER = "💌"
HEART_WITH_ARROW = "💘"
HEART_WITH_RIBBON = "💝"
SPARKLING_HEART = "💖"
GROWING_HEART = "💗"
BEATING_HEART = "💓"
REVOLVING_HEARTS = "💞"
TWO_HEARTS = "💕"
HEART_DECORATION = "💟"
HEART_EXCLAMATION = "❣"
BROKEN_HEART = "💔"
RED_HEART = "❤"
ORANGE_HEART = "🧡"
YELLOW_HEART = "💛"
GREEN_HEART = "💚"
BLUE_HEART = "💙"
PURPLE_HEART = "💜"
BROWN_HEART = "🤎"
BLACK_HEART = "🖤"
WHITE_HEART = "🤍"
HUNDRED_POINTS = "💯"
ANGER_SYMBOL = "💢"
COLLISION = "💥"
DIZZY = "💫"
SWEAT_DROPLETS = "💦"
DASHING_AWAY = "💨"
HOLE = "🕳"
BOMB = "💣"
SPEECH_BALLOON = "💬"
EYE_IN_SPEECH_BUBBLE = "👁️‍🗨️"
LEFT_SPEECH_BUBBLE = "🗨"
RIGHT_ANGER_BUBBLE = "🗯"
THOUGHT_BALLOON = "💭"
ZZZ = "💤"
WAVING_HAND = "👋"
RAISED_BACK_OF_HAND = "🤚"
HAND_WITH_FINGERS_SPLAYED = "🖐"
RAISED_HAND = "✋"
VULCAN_SALUTE = "🖖"
OK_HAND = "👌"
PINCHING_HAND = "🤏"
VICTORY_HAND = "✌"
CROSSED_FINGERS = "🤞"
LOVEYOU_GESTURE = "🤟"
SIGN_OF_THE_HORNS = "🤘"
CALL_ME_HAND = "🤙"
BACKHAND_INDEX_POINTING_LEFT = "👈"
BACKHAND_INDEX_POINTING_RIGHT = "👉"
BACKHAND_INDEX_POINTING_UP = "👆"
MIDDLE_FINGER = "🖕"
BACKHAND_INDEX_POINTING_DOWN = "👇"
INDEX_POINTING_UP = "☝"
THUMBS_UP = "👍"
THUMBS_DOWN = "👎"
RAISED_FIST = "✊"
ONCOMING_FIST = "👊"
LEFTFACING_FIST = "🤛"
RIGHTFACING_FIST = "🤜"
CLAPPING_HANDS = "👏"
RAISING_HANDS = "🙌"
OPEN_HANDS = "👐"
PALMS_UP_TOGETHER = "🤲"
HANDSHAKE = "🤝"
FOLDED_HANDS = "🙏"
WRITING_HAND = "✍"
NAIL_POLISH = "💅"
SELFIE = "🤳"
FLEXED_BICEPS = "💪"
MECHANICAL_ARM = "🦾"
MECHANICAL_LEG = "🦿"
LEG = "🦵"
FOOT = "🦶"
EAR = "👂"
EAR_WITH_HEARING_AID = "🦻"
NOSE = "👃"
BRAIN = "🧠"
TOOTH = "🦷"
BONE = "🦴"
EYES = "👀"
EYE = "👁"
TONGUE = "👅"
MOUTH = "👄"
BABY = "👶"
CHILD = "🧒"
BOY = "👦"
GIRL = "👧"
PERSON = "🧑"
PERSON_BLOND_HAIR = "👱"
MAN = "👨"
MAN_BEARD = "🧔"
MAN_BLOND_HAIR = "👱‍♂️"
MAN_RED_HAIR = "👨‍🦰"
MAN_CURLY_HAIR = "👨‍🦱"
MAN_WHITE_HAIR = "👨‍🦳"
MAN_BALD = "👨‍🦲"
WOMAN = "👩"
WOMAN_BLOND_HAIR = "👱‍♀️"
WOMAN_RED_HAIR = "👩‍🦰"
WOMAN_CURLY_HAIR = "👩‍🦱"
WOMAN_WHITE_HAIR = "👩‍🦳"
WOMAN_BALD = "👩‍🦲"
OLDER_PERSON = "🧓"
OLD_MAN = "👴"
OLD_WOMAN = "👵"
PERSON_FROWNING = "🙍"
MAN_FROWNING = "🙍‍♂️"
WOMAN_FROWNING = "🙍‍♀️"
PERSON_POUTING = "🙎"
MAN_POUTING = "🙎‍♂️"
WOMAN_POUTING = "🙎‍♀️"
PERSON_GESTURING_NO = "🙅"
MAN_GESTURING_NO = "🙅‍♂️"
WOMAN_GESTURING_NO = "🙅‍♀️"
PERSON_GESTURING_OK = "🙆"
MAN_GESTURING_OK = "🙆‍♂️"
WOMAN_GESTURING_OK = "🙆‍♀️"
PERSON_TIPPING_HAND = "💁"
MAN_TIPPING_HAND = "💁‍♂️"
WOMAN_TIPPING_HAND = "💁‍♀️"
PERSON_RAISING_HAND = "🙋"
MAN_RAISING_HAND = "🙋‍♂️"
WOMAN_RAISING_HAND = "🙋‍♀️"
DEAF_PERSON = "🧏"
DEAF_MAN = "🧏‍♂️"
DEAF_WOMAN = "🧏‍♀️"
PERSON_BOWING = "🙇"
MAN_BOWING = "🙇‍♂️"
WOMAN_BOWING = "🙇‍♀️"
PERSON_FACEPALMING = "🤦"
MAN_FACEPALMING = "🤦‍♂️"
WOMAN_FACEPALMING = "🤦‍♀️"
PERSON_SHRUGGING = "🤷"
MAN_SHRUGGING = "🤷‍♂️"
WOMAN_SHRUGGING = "🤷‍♀️"
MAN_HEALTH_WORKER = "👨‍⚕️"
WOMAN_HEALTH_WORKER = "👩‍⚕️"
MAN_STUDENT = "👨‍🎓"
WOMAN_STUDENT = "👩‍🎓"
MAN_TEACHER = "👨‍🏫"
WOMAN_TEACHER = "👩‍🏫"
MAN_JUDGE = "👨‍⚖️"
WOMAN_JUDGE = "👩‍⚖️"
MAN_FARMER = "👨‍🌾"
WOMAN_FARMER = "👩‍🌾"
MAN_COOK = "👨‍🍳"
WOMAN_COOK = "👩‍🍳"
MAN_MECHANIC = "👨‍🔧"
WOMAN_MECHANIC = "👩‍🔧"
MAN_FACTORY_WORKER = "👨‍🏭"
WOMAN_FACTORY_WORKER = "👩‍🏭"
MAN_OFFICE_WORKER = "👨‍💼"
WOMAN_OFFICE_WORKER = "👩‍💼"
MAN_SCIENTIST = "👨‍🔬"
WOMAN_SCIENTIST = "👩‍🔬"
MAN_TECHNOLOGIST = "👨‍💻"
WOMAN_TECHNOLOGIST = "👩‍💻"
MAN_SINGER = "👨‍🎤"
WOMAN_SINGER = "👩‍🎤"
MAN_ARTIST = "👨‍🎨"
WOMAN_ARTIST = "👩‍🎨"
MAN_PILOT = "👨‍✈️"
WOMAN_PILOT = "👩‍✈️"
MAN_ASTRONAUT = "👨‍🚀"
WOMAN_ASTRONAUT = "👩‍🚀"
MAN_FIREFIGHTER = "👨‍🚒"
WOMAN_FIREFIGHTER = "👩‍🚒"
POLICE_OFFICER = "👮"
MAN_POLICE_OFFICER = "👮‍♂️"
WOMAN_POLICE_OFFICER = "👮‍♀️"
DETECTIVE = "🕵"
MAN_DETECTIVE = "🕵️‍♂️"
WOMAN_DETECTIVE = "🕵️‍♀️"
GUARD = "💂"
MAN_GUARD = "💂‍♂️"
WOMAN_GUARD = "💂‍♀️"
CONSTRUCTION_WORKER = "👷"
MAN_CONSTRUCTION_WORKER = "👷‍♂️"
WOMAN_CONSTRUCTION_WORKER = "👷‍♀️"
PRINCE = "🤴"
PRINCESS = "👸"
PERSON_WEARING_TURBAN = "👳"
MAN_WEARING_TURBAN = "👳‍♂️"
WOMAN_WEARING_TURBAN = "👳‍♀️"
MAN_WITH_CHINESE_CAP = "👲"
WOMAN_WITH_HEADSCARF = "🧕"
MAN_IN_TUXEDO = "🤵"
BRIDE_WITH_VEIL = "👰"
PREGNANT_WOMAN = "🤰"
BREASTFEEDING = "🤱"
BABY_ANGEL = "👼"
SANTA_CLAUS = "🎅"
MRS_CLAUS = "🤶"
SUPERHERO = "🦸"
MAN_SUPERHERO = "🦸‍♂️"
WOMAN_SUPERHERO = "🦸‍♀️"
SUPERVILLAIN = "🦹"
MAN_SUPERVILLAIN = "🦹‍♂️"
WOMAN_SUPERVILLAIN = "🦹‍♀️"
MAGE = "🧙"
MAN_MAGE = "🧙‍♂️"
WOMAN_MAGE = "🧙‍♀️"
FAIRY = "🧚"
MAN_FAIRY = "🧚‍♂️"
WOMAN_FAIRY = "🧚‍♀️"
VAMPIRE = "🧛"
MAN_VAMPIRE = "🧛‍♂️"
WOMAN_VAMPIRE = "🧛‍♀️"
MERPERSON = "🧜"
MERMAN = "🧜‍♂️"
MERMAID = "🧜‍♀️"
ELF = "🧝"
MAN_ELF = "🧝‍♂️"
WOMAN_ELF = "🧝‍♀️"
GENIE = "🧞"
MAN_GENIE = "🧞‍♂️"
WOMAN_GENIE = "🧞‍♀️"
ZOMBIE = "🧟"
MAN_ZOMBIE = "🧟‍♂️"
WOMAN_ZOMBIE = "🧟‍♀️"
PERSON_GETTING_MASSAGE = "💆"
MAN_GETTING_MASSAGE = "💆‍♂️"
WOMAN_GETTING_MASSAGE = "💆‍♀️"
PERSON_GETTING_HAIRCUT = "💇"
MAN_GETTING_HAIRCUT = "💇‍♂️"
WOMAN_GETTING_HAIRCUT = "💇‍♀️"
PERSON_WALKING = "🚶"
MAN_WALKING = "🚶‍♂️"
WOMAN_WALKING = "🚶‍♀️"
PERSON_STANDING = "🧍"
MAN_STANDING = "🧍‍♂️"
WOMAN_STANDING = "🧍‍♀️"
PERSON_KNEELING = "🧎"
MAN_KNEELING = "🧎‍♂️"
WOMAN_KNEELING = "🧎‍♀️"
MAN_WITH_PROBING_CANE = "👨‍🦯"
WOMAN_WITH_PROBING_CANE = "👩‍🦯"
MAN_IN_MOTORIZED_WHEELCHAIR = "👨‍🦼"
WOMAN_IN_MOTORIZED_WHEELCHAIR = "👩‍🦼"
MAN_IN_MANUAL_WHEELCHAIR = "👨‍🦽"
WOMAN_IN_MANUAL_WHEELCHAIR = "👩‍🦽"
PERSON_RUNNING = "🏃"
MAN_RUNNING = "🏃‍♂️"
WOMAN_RUNNING = "🏃‍♀️"
WOMAN_DANCING = "💃"
MAN_DANCING = "🕺"
MAN_IN_SUIT_LEVITATING = "🕴"
PEOPLE_WITH_BUNNY_EARS = "👯"
MEN_WITH_BUNNY_EARS = "👯‍♂️"
WOMEN_WITH_BUNNY_EARS = "👯‍♀️"
PERSON_IN_STEAMY_ROOM = "🧖"
MAN_IN_STEAMY_ROOM = "🧖‍♂️"
WOMAN_IN_STEAMY_ROOM = "🧖‍♀️"
PERSON_CLIMBING = "🧗"
MAN_CLIMBING = "🧗‍♂️"
WOMAN_CLIMBING = "🧗‍♀️"
PERSON_FENCING = "🤺"
HORSE_RACING = "🏇"
SKIER = "⛷"
SNOWBOARDER = "🏂"
PERSON_GOLFING = "🏌"
MAN_GOLFING = "🏌️‍♂️"
WOMAN_GOLFING = "🏌️‍♀️"
PERSON_SURFING = "🏄"
MAN_SURFING = "🏄‍♂️"
WOMAN_SURFING = "🏄‍♀️"
PERSON_ROWING_BOAT = "🚣"
MAN_ROWING_BOAT = "🚣‍♂️"
WOMAN_ROWING_BOAT = "🚣‍♀️"
PERSON_SWIMMING = "🏊"
MAN_SWIMMING = "🏊‍♂️"
WOMAN_SWIMMING = "🏊‍♀️"
PERSON_BOUNCING_BALL = "⛹"
MAN_BOUNCING_BALL = "⛹️‍♂️"
WOMAN_BOUNCING_BALL = "⛹️‍♀️"
PERSON_LIFTING_WEIGHTS = "🏋"
MAN_LIFTING_WEIGHTS = "🏋️‍♂️"
WOMAN_LIFTING_WEIGHTS = "🏋️‍♀️"
PERSON_BIKING = "🚴"
MAN_BIKING = "🚴‍♂️"
WOMAN_BIKING = "🚴‍♀️"
PERSON_MOUNTAIN_BIKING = "🚵"
MAN_MOUNTAIN_BIKING = "🚵‍♂️"
WOMAN_MOUNTAIN_BIKING = "🚵‍♀️"
PERSON_CARTWHEELING = "🤸"
MAN_CARTWHEELING = "🤸‍♂️"
WOMAN_CARTWHEELING = "🤸‍♀️"
PEOPLE_WRESTLING = "🤼"
MEN_WRESTLING = "🤼‍♂️"
WOMEN_WRESTLING = "🤼‍♀️"
PERSON_PLAYING_WATER_POLO = "🤽"
MAN_PLAYING_WATER_POLO = "🤽‍♂️"
WOMAN_PLAYING_WATER_POLO = "🤽‍♀️"
PERSON_PLAYING_HANDBALL = "🤾"
MAN_PLAYING_HANDBALL = "🤾‍♂️"
WOMAN_PLAYING_HANDBALL = "🤾‍♀️"
PERSON_JUGGLING = "🤹"
MAN_JUGGLING = "🤹‍♂️"
WOMAN_JUGGLING = "🤹‍♀️"
PERSON_IN_LOTUS_POSITION = "🧘"
MAN_IN_LOTUS_POSITION = "🧘‍♂️"
WOMAN_IN_LOTUS_POSITION = "🧘‍♀️"
PERSON_TAKING_BATH = "🛀"
PERSON_IN_BED = "🛌"
PEOPLE_HOLDING_HANDS = "🧑‍🤝‍🧑"
WOMEN_HOLDING_HANDS = "👭"
WOMAN_AND_MAN_HOLDING_HANDS = "👫"
MEN_HOLDING_HANDS = "👬"
KISS = "💏"
KISS_WOMAN_MAN = "👩‍❤️‍💋‍👨"
KISS_MAN_MAN = "👨‍❤️‍💋‍👨"
KISS_WOMAN_WOMAN = "👩‍❤️‍💋‍👩"
COUPLE_WITH_HEART = "💑"
COUPLE_WITH_HEART_WOMAN_MAN = "👩‍❤️‍👨"
COUPLE_WITH_HEART_MAN_MAN = "👨‍❤️‍👨"
COUPLE_WITH_HEART_WOMAN_WOMAN = "👩‍❤️‍👩"
FAMILY = "👪"
FAMILY_MAN_WOMAN_BOY = "👨‍👩‍👦"
FAMILY_MAN_WOMAN_GIRL = "👨‍👩‍👧"
FAMILY_MAN_WOMAN_GIRL_BOY = "👨‍👩‍👧‍👦"
FAMILY_MAN_WOMAN_BOY_BOY = "👨‍👩‍👦‍👦"
FAMILY_MAN_WOMAN_GIRL_GIRL = "👨‍👩‍👧‍👧"
FAMILY_MAN_MAN_BOY = "👨‍👨‍👦"
FAMILY_MAN_MAN_GIRL = "👨‍👨‍👧"
FAMILY_MAN_MAN_GIRL_BOY = "👨‍👨‍👧‍👦"
FAMILY_MAN_MAN_BOY_BOY = "👨‍👨‍👦‍👦"
FAMILY_MAN_MAN_GIRL_GIRL = "👨‍👨‍👧‍👧"
FAMILY_WOMAN_WOMAN_BOY = "👩‍👩‍👦"
FAMILY_WOMAN_WOMAN_GIRL = "👩‍👩‍👧"
FAMILY_WOMAN_WOMAN_GIRL_BOY = "👩‍👩‍👧‍👦"
FAMILY_WOMAN_WOMAN_BOY_BOY = "👩‍👩‍👦‍👦"
FAMILY_WOMAN_WOMAN_GIRL_GIRL = "👩‍👩‍👧‍👧"
FAMILY_MAN_BOY = "👨‍👦"
FAMILY_MAN_BOY_BOY = "👨‍👦‍👦"
FAMILY_MAN_GIRL = "👨‍👧"
FAMILY_MAN_GIRL_BOY = "👨‍👧‍👦"
FAMILY_MAN_GIRL_GIRL = "👨‍👧‍👧"
FAMILY_WOMAN_BOY = "👩‍👦"
FAMILY_WOMAN_BOY_BOY = "👩‍👦‍👦"
FAMILY_WOMAN_GIRL = "👩‍👧"
FAMILY_WOMAN_GIRL_BOY = "👩‍👧‍👦"
FAMILY_WOMAN_GIRL_GIRL = "👩‍👧‍👧"
SPEAKING_HEAD = "🗣"
BUST_IN_SILHOUETTE = "👤"
BUSTS_IN_SILHOUETTE = "👥"
FOOTPRINTS = "👣"
RED_HAIR = "🦰"
CURLY_HAIR = "🦱"
WHITE_HAIR = "🦳"
BALD = "🦲"
MONKEY_FACE = "🐵"
MONKEY = "🐒"
GORILLA = "🦍"
ORANGUTAN = "🦧"
DOG_FACE = "🐶"
DOG = "🐕"
GUIDE_DOG = "🦮"
SERVICE_DOG = "🐕‍🦺"
POODLE = "🐩"
WOLF = "🐺"
FOX = "🦊"
RACCOON = "🦝"
CAT_FACE = "🐱"
CAT = "🐈"
LION = "🦁"
TIGER_FACE = "🐯"
TIGER = "🐅"
LEOPARD = "🐆"
HORSE_FACE = "🐴"
HORSE = "🐎"
UNICORN = "🦄"
ZEBRA = "🦓"
DEER = "🦌"
COW_FACE = "🐮"
OX = "🐂"
WATER_BUFFALO = "🐃"
COW = "🐄"
PIG_FACE = "🐷"
PIG = "🐖"
BOAR = "🐗"
PIG_NOSE = "🐽"
RAM = "🐏"
EWE = "🐑"
GOAT = "🐐"
CAMEL = "🐪"
TWOHUMP_CAMEL = "🐫"
LLAMA = "🦙"
GIRAFFE = "🦒"
ELEPHANT = "🐘"
RHINOCEROS = "🦏"
HIPPOPOTAMUS = "🦛"
MOUSE_FACE = "🐭"
MOUSE = "🐁"
RAT = "🐀"
HAMSTER = "🐹"
RABBIT_FACE = "🐰"
RABBIT = "🐇"
CHIPMUNK = "🐿"
HEDGEHOG = "🦔"
BAT = "🦇"
BEAR = "🐻"
KOALA = "🐨"
PANDA = "🐼"
SLOTH = "🦥"
OTTER = "🦦"
SKUNK = "🦨"
KANGAROO = "🦘"
BADGER = "🦡"
PAW_PRINTS = "🐾"
TURKEY = "🦃"
CHICKEN = "🐔"
ROOSTER = "🐓"
HATCHING_CHICK = "🐣"
BABY_CHICK = "🐤"
FRONTFACING_BABY_CHICK = "🐥"
BIRD = "🐦"
PENGUIN = "🐧"
DOVE = "🕊"
EAGLE = "🦅"
DUCK = "🦆"
SWAN = "🦢"
OWL = "🦉"
FLAMINGO = "🦩"
PEACOCK = "🦚"
PARROT = "🦜"
FROG = "🐸"
CROCODILE = "🐊"
TURTLE = "🐢"
LIZARD = "🦎"
SNAKE = "🐍"
DRAGON_FACE = "🐲"
DRAGON = "🐉"
SAUROPOD = "🦕"
TREX = "🦖"
SPOUTING_WHALE = "🐳"
WHALE = "🐋"
DOLPHIN = "🐬"
FISH = "🐟"
TROPICAL_FISH = "🐠"
BLOWFISH = "🐡"
SHARK = "🦈"
OCTOPUS = "🐙"
SPIRAL_SHELL = "🐚"
SNAIL = "🐌"
BUTTERFLY = "🦋"
BUG = "🐛"
ANT = "🐜"
HONEYBEE = "🐝"
LADY_BEETLE = "🐞"
CRICKET = "🦗"
SPIDER = "🕷"
SPIDER_WEB = "🕸"
SCORPION = "🦂"
MOSQUITO = "🦟"
MICROBE = "🦠"
BOUQUET = "💐"
CHERRY_BLOSSOM = "🌸"
WHITE_FLOWER = "💮"
ROSETTE = "🏵"
ROSE = "🌹"
WILTED_FLOWER = "🥀"
HIBISCUS = "🌺"
SUNFLOWER = "🌻"
BLOSSOM = "🌼"
TULIP = "🌷"
SEEDLING = "🌱"
EVERGREEN_TREE = "🌲"
DECIDUOUS_TREE = "🌳"
PALM_TREE = "🌴"
CACTUS = "🌵"
SHEAF_OF_RICE = "🌾"
HERB = "🌿"
SHAMROCK = "☘"
FOUR_LEAF_CLOVER = "🍀"
MAPLE_LEAF = "🍁"
FALLEN_LEAF = "🍂"
LEAF_FLUTTERING_IN_WIND = "🍃"
GRAPES = "🍇"
MELON = "🍈"
WATERMELON = "🍉"
TANGERINE = "🍊"
LEMON = "🍋"
BANANA = "🍌"
PINEAPPLE = "🍍"
MANGO = "🥭"
RED_APPLE = "🍎"
GREEN_APPLE = "🍏"
PEAR = "🍐"
PEACH = "🍑"
CHERRIES = "🍒"
STRAWBERRY = "🍓"
KIWI_FRUIT = "🥝"
TOMATO = "🍅"
COCONUT = "🥥"
AVOCADO = "🥑"
EGGPLANT = "🍆"
POTATO = "🥔"
CARROT = "🥕"
EAR_OF_CORN = "🌽"
HOT_PEPPER = "🌶"
CUCUMBER = "🥒"
LEAFY_GREEN = "🥬"
BROCCOLI = "🥦"
GARLIC = "🧄"
ONION = "🧅"
MUSHROOM = "🍄"
PEANUTS = "🥜"
CHESTNUT = "🌰"
BREAD = "🍞"
CROISSANT = "🥐"
BAGUETTE_BREAD = "🥖"
PRETZEL = "🥨"
BAGEL = "🥯"
PANCAKES = "🥞"
WAFFLE = "🧇"
CHEESE_WEDGE = "🧀"
MEAT_ON_BONE = "🍖"
POULTRY_LEG = "🍗"
CUT_OF_MEAT = "🥩"
BACON = "🥓"
HAMBURGER = "🍔"
FRENCH_FRIES = "🍟"
PIZZA = "🍕"
HOT_DOG = "🌭"
SANDWICH = "🥪"
TACO = "🌮"
BURRITO = "🌯"
STUFFED_FLATBREAD = "🥙"
FALAFEL = "🧆"
EGG = "🥚"
COOKING = "🍳"
SHALLOW_PAN_OF_FOOD = "🥘"
POT_OF_FOOD = "🍲"
BOWL_WITH_SPOON = "🥣"
GREEN_SALAD = "🥗"
POPCORN = "🍿"
BUTTER = "🧈"
SALT = "🧂"
CANNED_FOOD = "🥫"
BENTO_BOX = "🍱"
RICE_CRACKER = "🍘"
RICE_BALL = "🍙"
COOKED_RICE = "🍚"
CURRY_RICE = "🍛"
STEAMING_BOWL = "🍜"
SPAGHETTI = "🍝"
ROASTED_SWEET_POTATO = "🍠"
ODEN = "🍢"
SUSHI = "🍣"
FRIED_SHRIMP = "🍤"
FISH_CAKE_WITH_SWIRL = "🍥"
MOON_CAKE = "🥮"
DANGO = "🍡"
DUMPLING = "🥟"
FORTUNE_COOKIE = "🥠"
TAKEOUT_BOX = "🥡"
CRAB = "🦀"
LOBSTER = "🦞"
SHRIMP = "🦐"
SQUID = "🦑"
OYSTER = "🦪"
SOFT_ICE_CREAM = "🍦"
SHAVED_ICE = "🍧"
ICE_CREAM = "🍨"
DOUGHNUT = "🍩"
COOKIE = "🍪"
BIRTHDAY_CAKE = "🎂"
SHORTCAKE = "🍰"
CUPCAKE = "🧁"
PIE = "🥧"
CHOCOLATE_BAR = "🍫"
CANDY = "🍬"
LOLLIPOP = "🍭"
CUSTARD = "🍮"
HONEY_POT = "🍯"
BABY_BOTTLE = "🍼"
GLASS_OF_MILK = "🥛"
HOT_BEVERAGE = "☕"
TEACUP_WITHOUT_HANDLE = "🍵"
SAKE = "🍶"
BOTTLE_WITH_POPPING_CORK = "🍾"
WINE_GLASS = "🍷"
COCKTAIL_GLASS = "🍸"
TROPICAL_DRINK = "🍹"
BEER_MUG = "🍺"
CLINKING_BEER_MUGS = "🍻"
CLINKING_GLASSES = "🥂"
TUMBLER_GLASS = "🥃"
CUP_WITH_STRAW = "🥤"
BEVERAGE_BOX = "🧃"
MATE = "🧉"
ICE = "🧊"
CHOPSTICKS = "🥢"
FORK_AND_KNIFE_WITH_PLATE = "🍽"
FORK_AND_KNIFE = "🍴"
SPOON = "🥄"
KITCHEN_KNIFE = "🔪"
AMPHORA = "🏺"
GLOBE_SHOWING_EUROPEAFRICA = "🌍"
GLOBE_SHOWING_AMERICAS = "🌎"
GLOBE_SHOWING_ASIAAUSTRALIA = "🌏"
GLOBE_WITH_MERIDIANS = "🌐"
WORLD_MAP = "🗺"
MAP_OF_JAPAN = "🗾"
COMPASS = "🧭"
SNOWCAPPED_MOUNTAIN = "🏔"
MOUNTAIN = "⛰"
VOLCANO = "🌋"
MOUNT_FUJI = "🗻"
CAMPING = "🏕"
BEACH_WITH_UMBRELLA = "🏖"
DESERT = "🏜"
DESERT_ISLAND = "🏝"
NATIONAL_PARK = "🏞"
STADIUM = "🏟"
CLASSICAL_BUILDING = "🏛"
BUILDING_CONSTRUCTION = "🏗"
BRICK = "🧱"
HOUSES = "🏘"
DERELICT_HOUSE = "🏚"
HOUSE = "🏠"
HOUSE_WITH_GARDEN = "🏡"
OFFICE_BUILDING = "🏢"
JAPANESE_POST_OFFICE = "🏣"
POST_OFFICE = "🏤"
HOSPITAL = "🏥"
BANK = "🏦"
HOTEL = "🏨"
LOVE_HOTEL = "🏩"
CONVENIENCE_STORE = "🏪"
SCHOOL = "🏫"
DEPARTMENT_STORE = "🏬"
FACTORY = "🏭"
JAPANESE_CASTLE = "🏯"
CASTLE = "🏰"
WEDDING = "💒"
TOKYO_TOWER = "🗼"
STATUE_OF_LIBERTY = "🗽"
CHURCH = "⛪"
MOSQUE = "🕌"
HINDU_TEMPLE = "🛕"
SYNAGOGUE = "🕍"
SHINTO_SHRINE = "⛩"
KAABA = "🕋"
FOUNTAIN = "⛲"
TENT = "⛺"
FOGGY = "🌁"
NIGHT_WITH_STARS = "🌃"
CITYSCAPE = "🏙"
SUNRISE_OVER_MOUNTAINS = "🌄"
SUNRISE = "🌅"
CITYSCAPE_AT_DUSK = "🌆"
SUNSET = "🌇"
BRIDGE_AT_NIGHT = "🌉"
HOT_SPRINGS = "♨"
CAROUSEL_HORSE = "🎠"
FERRIS_WHEEL = "🎡"
ROLLER_COASTER = "🎢"
BARBER_POLE = "💈"
CIRCUS_TENT = "🎪"
LOCOMOTIVE = "🚂"
RAILWAY_CAR = "🚃"
HIGHSPEED_TRAIN = "🚄"
BULLET_TRAIN = "🚅"
TRAIN = "🚆"
METRO = "🚇"
LIGHT_RAIL = "🚈"
STATION = "🚉"
TRAM = "🚊"
MONORAIL = "🚝"
MOUNTAIN_RAILWAY = "🚞"
TRAM_CAR = "🚋"
BUS = "🚌"
ONCOMING_BUS = "🚍"
TROLLEYBUS = "🚎"
MINIBUS = "🚐"
AMBULANCE = "🚑"
FIRE_ENGINE = "🚒"
POLICE_CAR = "🚓"
ONCOMING_POLICE_CAR = "🚔"
TAXI = "🚕"
ONCOMING_TAXI = "🚖"
AUTOMOBILE = "🚗"
ONCOMING_AUTOMOBILE = "🚘"
SPORT_UTILITY_VEHICLE = "🚙"
DELIVERY_TRUCK = "🚚"
ARTICULATED_LORRY = "🚛"
TRACTOR = "🚜"
RACING_CAR = "🏎"
MOTORCYCLE = "🏍"
MOTOR_SCOOTER = "🛵"
MANUAL_WHEELCHAIR = "🦽"
MOTORIZED_WHEELCHAIR = "🦼"
AUTO_RICKSHAW = "🛺"
BICYCLE = "🚲"
KICK_SCOOTER = "🛴"
SKATEBOARD = "🛹"
BUS_STOP = "🚏"
MOTORWAY = "🛣"
RAILWAY_TRACK = "🛤"
OIL_DRUM = "🛢"
FUEL_PUMP = "⛽"
POLICE_CAR_LIGHT = "🚨"
HORIZONTAL_TRAFFIC_LIGHT = "🚥"
VERTICAL_TRAFFIC_LIGHT = "🚦"
STOP_SIGN = "🛑"
CONSTRUCTION = "🚧"
ANCHOR = "⚓"
SAILBOAT = "⛵"
CANOE = "🛶"
SPEEDBOAT = "🚤"
PASSENGER_SHIP = "🛳"
FERRY = "⛴"
MOTOR_BOAT = "🛥"
SHIP = "🚢"
AIRPLANE = "✈"
SMALL_AIRPLANE = "🛩"
AIRPLANE_DEPARTURE = "🛫"
AIRPLANE_ARRIVAL = "🛬"
PARACHUTE = "🪂"
SEAT = "💺"
HELICOPTER = "🚁"
SUSPENSION_RAILWAY = "🚟"
MOUNTAIN_CABLEWAY = "🚠"
AERIAL_TRAMWAY = "🚡"
SATELLITE = "🛰"
ROCKET = "🚀"
FLYING_SAUCER = "🛸"
BELLHOP_BELL = "🛎"
LUGGAGE = "🧳"
HOURGLASS_DONE = "⌛"
HOURGLASS_NOT_DONE = "⏳"
WATCH = "⌚"
ALARM_CLOCK = "⏰"
STOPWATCH = "⏱"
TIMER_CLOCK = "⏲"
MANTELPIECE_CLOCK = "🕰"
TWELVE_OCLOCK = "🕛"
TWELVETHIRTY = "🕧"
ONE_OCLOCK = "🕐"
ONETHIRTY = "🕜"
TWO_OCLOCK = "🕑"
TWOTHIRTY = "🕝"
THREE_OCLOCK = "🕒"
THREETHIRTY = "🕞"
FOUR_OCLOCK = "🕓"
FOURTHIRTY = "🕟"
FIVE_OCLOCK = "🕔"
FIVETHIRTY = "🕠"
SIX_OCLOCK = "🕕"
SIXTHIRTY = "🕡"
SEVEN_OCLOCK = "🕖"
SEVENTHIRTY = "🕢"
EIGHT_OCLOCK = "🕗"
EIGHTTHIRTY = "🕣"
NINE_OCLOCK = "🕘"
NINETHIRTY = "🕤"
TEN_OCLOCK = "🕙"
TENTHIRTY = "🕥"
ELEVEN_OCLOCK = "🕚"
ELEVENTHIRTY = "🕦"
NEW_MOON = "🌑"
WAXING_CRESCENT_MOON = "🌒"
FIRST_QUARTER_MOON = "🌓"
WAXING_GIBBOUS_MOON = "🌔"
FULL_MOON = "🌕"
WANING_GIBBOUS_MOON = "🌖"
LAST_QUARTER_MOON = "🌗"
WANING_CRESCENT_MOON = "🌘"
CRESCENT_MOON = "🌙"
NEW_MOON_FACE = "🌚"
FIRST_QUARTER_MOON_FACE = "🌛"
LAST_QUARTER_MOON_FACE = "🌜"
THERMOMETER = "🌡"
SUN = "☀"
FULL_MOON_FACE = "🌝"
SUN_WITH_FACE = "🌞"
RINGED_PLANET = "🪐"
STAR = "⭐"
GLOWING_STAR = "🌟"
SHOOTING_STAR = "🌠"
MILKY_WAY = "🌌"
CLOUD = "☁"
SUN_BEHIND_CLOUD = "⛅"
CLOUD_WITH_LIGHTNING_AND_RAIN = "⛈"
SUN_BEHIND_SMALL_CLOUD = "🌤"
SUN_BEHIND_LARGE_CLOUD = "🌥"
SUN_BEHIND_RAIN_CLOUD = "🌦"
CLOUD_WITH_RAIN = "🌧"
CLOUD_WITH_SNOW = "🌨"
CLOUD_WITH_LIGHTNING = "🌩"
TORNADO = "🌪"
FOG = "🌫"
WIND_FACE = "🌬"
CYCLONE = "🌀"
RAINBOW = "🌈"
CLOSED_UMBRELLA = "🌂"
UMBRELLA = "☂"
UMBRELLA_WITH_RAIN_DROPS = "☔"
UMBRELLA_ON_GROUND = "⛱"
HIGH_VOLTAGE = "⚡"
SNOWFLAKE = "❄"
SNOWMAN = "☃"
SNOWMAN_WITHOUT_SNOW = "⛄"
COMET = "☄"
FIRE = "🔥"
DROPLET = "💧"
WATER_WAVE = "🌊"
JACKOLANTERN = "🎃"
CHRISTMAS_TREE = "🎄"
FIREWORKS = "🎆"
SPARKLER = "🎇"
FIRECRACKER = "🧨"
SPARKLES = "✨"
BALLOON = "🎈"
PARTY_POPPER = "🎉"
CONFETTI_BALL = "🎊"
TANABATA_TREE = "🎋"
PINE_DECORATION = "🎍"
JAPANESE_DOLLS = "🎎"
CARP_STREAMER = "🎏"
WIND_CHIME = "🎐"
MOON_VIEWING_CEREMONY = "🎑"
RED_ENVELOPE = "🧧"
RIBBON = "🎀"
WRAPPED_GIFT = "🎁"
REMINDER_RIBBON = "🎗"
ADMISSION_TICKETS = "🎟"
TICKET = "🎫"
MILITARY_MEDAL = "🎖"
TROPHY = "🏆"
SPORTS_MEDAL = "🏅"
_1ST_PLACE_MEDAL = "🥇"
_2ND_PLACE_MEDAL = "🥈"
_3RD_PLACE_MEDAL = "🥉"
SOCCER_BALL = "⚽"
BASEBALL = "⚾"
SOFTBALL = "🥎"
BASKETBALL = "🏀"
VOLLEYBALL = "🏐"
AMERICAN_FOOTBALL = "🏈"
RUGBY_FOOTBALL = "🏉"
TENNIS = "🎾"
FLYING_DISC = "🥏"
BOWLING = "🎳"
CRICKET_GAME = "🏏"
FIELD_HOCKEY = "🏑"
ICE_HOCKEY = "🏒"
LACROSSE = "🥍"
PING_PONG = "🏓"
BADMINTON = "🏸"
BOXING_GLOVE = "🥊"
MARTIAL_ARTS_UNIFORM = "🥋"
GOAL_NET = "🥅"
FLAG_IN_HOLE = "⛳"
ICE_SKATE = "⛸"
FISHING_POLE = "🎣"
DIVING_MASK = "🤿"
RUNNING_SHIRT = "🎽"
SKIS = "🎿"
SLED = "🛷"
CURLING_STONE = "🥌"
DIRECT_HIT = "🎯"
YOYO = "🪀"
KITE = "🪁"
POOL_8_BALL = "🎱"
CRYSTAL_BALL = "🔮"
NAZAR_AMULET = "🧿"
VIDEO_GAME = "🎮"
JOYSTICK = "🕹"
SLOT_MACHINE = "🎰"
GAME_DIE = "🎲"
PUZZLE_PIECE = "🧩"
TEDDY_BEAR = "🧸"
SPADE_SUIT = "♠"
HEART_SUIT = "♥"
DIAMOND_SUIT = "♦"
CLUB_SUIT = "♣"
CHESS_PAWN = "♟"
JOKER = "🃏"
MAHJONG_RED_DRAGON = "🀄"
FLOWER_PLAYING_CARDS = "🎴"
PERFORMING_ARTS = "🎭"
FRAMED_PICTURE = "🖼"
ARTIST_PALETTE = "🎨"
THREAD = "🧵"
YARN = "🧶"
GLASSES = "👓"
SUNGLASSES = "🕶"
GOGGLES = "🥽"
LAB_COAT = "🥼"
SAFETY_VEST = "🦺"
NECKTIE = "👔"
TSHIRT = "👕"
JEANS = "👖"
SCARF = "🧣"
GLOVES = "🧤"
COAT = "🧥"
SOCKS = "🧦"
DRESS = "👗"
KIMONO = "👘"
SARI = "🥻"
ONEPIECE_SWIMSUIT = "🩱"
BRIEFS = "🩲"
SHORTS = "🩳"
BIKINI = "👙"
WOMANS_CLOTHES = "👚"
PURSE = "👛"
HANDBAG = "👜"
CLUTCH_BAG = "👝"
SHOPPING_BAGS = "🛍"
BACKPACK = "🎒"
MANS_SHOE = "👞"
RUNNING_SHOE = "👟"
HIKING_BOOT = "🥾"
FLAT_SHOE = "🥿"
HIGHHEELED_SHOE = "👠"
WOMANS_SANDAL = "👡"
BALLET_SHOES = "🩰"
WOMANS_BOOT = "👢"
CROWN = "👑"
WOMANS_HAT = "👒"
TOP_HAT = "🎩"
GRADUATION_CAP = "🎓"
BILLED_CAP = "🧢"
RESCUE_WORKERS_HELMET = "⛑"
PRAYER_BEADS = "📿"
LIPSTICK = "💄"
RING = "💍"
GEM_STONE = "💎"
MUTED_SPEAKER = "🔇"
SPEAKER_LOW_VOLUME = "🔈"
SPEAKER_MEDIUM_VOLUME = "🔉"
SPEAKER_HIGH_VOLUME = "🔊"
LOUDSPEAKER = "📢"
MEGAPHONE = "📣"
POSTAL_HORN = "📯"
BELL = "🔔"
BELL_WITH_SLASH = "🔕"
MUSICAL_SCORE = "🎼"
MUSICAL_NOTE = "🎵"
MUSICAL_NOTES = "🎶"
STUDIO_MICROPHONE = "🎙"
LEVEL_SLIDER = "🎚"
CONTROL_KNOBS = "🎛"
MICROPHONE = "🎤"
HEADPHONE = "🎧"
RADIO = "📻"
SAXOPHONE = "🎷"
GUITAR = "🎸"
MUSICAL_KEYBOARD = "🎹"
TRUMPET = "🎺"
VIOLIN = "🎻"
BANJO = "🪕"
DRUM = "🥁"
MOBILE_PHONE = "📱"
MOBILE_PHONE_WITH_ARROW = "📲"
TELEPHONE = "☎"
TELEPHONE_RECEIVER = "📞"
PAGER = "📟"
FAX_MACHINE = "📠"
BATTERY = "🔋"
ELECTRIC_PLUG = "🔌"
LAPTOP_COMPUTER = "💻"
DESKTOP_COMPUTER = "🖥"
PRINTER = "🖨"
KEYBOARD = "⌨"
COMPUTER_MOUSE = "🖱"
TRACKBALL = "🖲"
COMPUTER_DISK = "💽"
FLOPPY_DISK = "💾"
OPTICAL_DISK = "💿"
DVD = "📀"
ABACUS = "🧮"
MOVIE_CAMERA = "🎥"
FILM_FRAMES = "🎞"
FILM_PROJECTOR = "📽"
CLAPPER_BOARD = "🎬"
TELEVISION = "📺"
CAMERA = "📷"
CAMERA_WITH_FLASH = "📸"
VIDEO_CAMERA = "📹"
VIDEOCASSETTE = "📼"
MAGNIFYING_GLASS_TILTED_LEFT = "🔍"
MAGNIFYING_GLASS_TILTED_RIGHT = "🔎"
CANDLE = "🕯"
LIGHT_BULB = "💡"
FLASHLIGHT = "🔦"
RED_PAPER_LANTERN = "🏮"
DIYA_LAMP = "🪔"
NOTEBOOK_WITH_DECORATIVE_COVER = "📔"
CLOSED_BOOK = "📕"
OPEN_BOOK = "📖"
GREEN_BOOK = "📗"
BLUE_BOOK = "📘"
ORANGE_BOOK = "📙"
BOOKS = "📚"
NOTEBOOK = "📓"
LEDGER = "📒"
PAGE_WITH_CURL = "📃"
SCROLL = "📜"
PAGE_FACING_UP = "📄"
NEWSPAPER = "📰"
ROLLEDUP_NEWSPAPER = "🗞"
BOOKMARK_TABS = "📑"
BOOKMARK = "🔖"
LABEL = "🏷"
MONEY_BAG = "💰"
YEN_BANKNOTE = "💴"
DOLLAR_BANKNOTE = "💵"
EURO_BANKNOTE = "💶"
POUND_BANKNOTE = "💷"
MONEY_WITH_WINGS = "💸"
CREDIT_CARD = "💳"
RECEIPT = "🧾"
CHART_INCREASING_WITH_YEN = "💹"
CURRENCY_EXCHANGE = "💱"
HEAVY_DOLLAR_SIGN = "💲"
ENVELOPE = "✉"
EMAIL = "📧"
INCOMING_ENVELOPE = "📨"
ENVELOPE_WITH_ARROW = "📩"
OUTBOX_TRAY = "📤"
INBOX_TRAY = "📥"
PACKAGE = "📦"
CLOSED_MAILBOX_WITH_RAISED_FLAG = "📫"
CLOSED_MAILBOX_WITH_LOWERED_FLAG = "📪"
OPEN_MAILBOX_WITH_RAISED_FLAG = "📬"
OPEN_MAILBOX_WITH_LOWERED_FLAG = "📭"
POSTBOX = "📮"
BALLOT_BOX_WITH_BALLOT = "🗳"
PENCIL = "✏"
BLACK_NIB = "✒"
FOUNTAIN_PEN = "🖋"
PEN = "🖊"
PAINTBRUSH = "🖌"
CRAYON = "🖍"
MEMO = "📝"
BRIEFCASE = "💼"
FILE_FOLDER = "📁"
OPEN_FILE_FOLDER = "📂"
CARD_INDEX_DIVIDERS = "🗂"
CALENDAR = "📅"
TEAROFF_CALENDAR = "📆"
SPIRAL_NOTEPAD = "🗒"
SPIRAL_CALENDAR = "🗓"
CARD_INDEX = "📇"
CHART_INCREASING = "📈"
CHART_DECREASING = "📉"
BAR_CHART = "📊"
CLIPBOARD = "📋"
PUSHPIN = "📌"
ROUND_PUSHPIN = "📍"
PAPERCLIP = "📎"
LINKED_PAPERCLIPS = "🖇"
STRAIGHT_RULER = "📏"
TRIANGULAR_RULER = "📐"
SCISSORS = "✂"
CARD_FILE_BOX = "🗃"
FILE_CABINET = "🗄"
WASTEBASKET = "🗑"
LOCKED = "🔒"
UNLOCKED = "🔓"
LOCKED_WITH_PEN = "🔏"
LOCKED_WITH_KEY = "🔐"
KEY = "🔑"
OLD_KEY = "🗝"
HAMMER = "🔨"
AXE = "🪓"
PICK = "⛏"
HAMMER_AND_PICK = "⚒"
HAMMER_AND_WRENCH = "🛠"
DAGGER = "🗡"
CROSSED_SWORDS = "⚔"
PISTOL = "🔫"
BOW_AND_ARROW = "🏹"
SHIELD = "🛡"
WRENCH = "🔧"
NUT_AND_BOLT = "🔩"
GEAR = "⚙"
CLAMP = "🗜"
BALANCE_SCALE = "⚖"
PROBING_CANE = "🦯"
LINK = "🔗"
CHAINS = "⛓"
TOOLBOX = "🧰"
MAGNET = "🧲"
ALEMBIC = "⚗"
TEST_TUBE = "🧪"
PETRI_DISH = "🧫"
DNA = "🧬"
MICROSCOPE = "🔬"
TELESCOPE = "🔭"
SATELLITE_ANTENNA = "📡"
SYRINGE = "💉"
DROP_OF_BLOOD = "🩸"
PILL = "💊"
ADHESIVE_BANDAGE = "🩹"
STETHOSCOPE = "🩺"
DOOR = "🚪"
BED = "🛏"
COUCH_AND_LAMP = "🛋"
CHAIR = "🪑"
TOILET = "🚽"
SHOWER = "🚿"
BATHTUB = "🛁"
RAZOR = "🪒"
LOTION_BOTTLE = "🧴"
SAFETY_PIN = "🧷"
BROOM = "🧹"
BASKET = "🧺"
ROLL_OF_PAPER = "🧻"
SOAP = "🧼"
SPONGE = "🧽"
FIRE_EXTINGUISHER = "🧯"
SHOPPING_CART = "🛒"
CIGARETTE = "🚬"
COFFIN = "⚰"
FUNERAL_URN = "⚱"
MOAI = "🗿"
ATM_SIGN = "🏧"
LITTER_IN_BIN_SIGN = "🚮"
POTABLE_WATER = "🚰"
WHEELCHAIR_SYMBOL = "♿"
MENS_ROOM = "🚹"
WOMENS_ROOM = "🚺"
RESTROOM = "🚻"
BABY_SYMBOL = "🚼"
WATER_CLOSET = "🚾"
PASSPORT_CONTROL = "🛂"
CUSTOMS = "🛃"
BAGGAGE_CLAIM = "🛄"
LEFT_LUGGAGE = "🛅"
WARNING = "⚠"
CHILDREN_CROSSING = "🚸"
NO_ENTRY = "⛔"
PROHIBITED = "🚫"
NO_BICYCLES = "🚳"
NO_SMOKING = "🚭"
NO_LITTERING = "🚯"
NONPOTABLE_WATER = "🚱"
NO_PEDESTRIANS = "🚷"
NO_MOBILE_PHONES = "📵"
NO_ONE_UNDER_EIGHTEEN = "🔞"
RADIOACTIVE = "☢"
BIOHAZARD = "☣"
UP_ARROW = "⬆"
UPRIGHT_ARROW = "↗"
RIGHT_ARROW = "➡"
DOWNRIGHT_ARROW = "↘"
DOWN_ARROW = "⬇"
DOWNLEFT_ARROW = "↙"
LEFT_ARROW = "⬅"
UPLEFT_ARROW = "↖"
UPDOWN_ARROW = "↕"
LEFTRIGHT_ARROW = "↔"
RIGHT_ARROW_CURVING_LEFT = "↩"
LEFT_ARROW_CURVING_RIGHT = "↪"
RIGHT_ARROW_CURVING_UP = "⤴"
RIGHT_ARROW_CURVING_DOWN = "⤵"
CLOCKWISE_VERTICAL_ARROWS = "🔃"
COUNTERCLOCKWISE_ARROWS_BUTTON = "🔄"
BACK_ARROW = "🔙"
END_ARROW = "🔚"
ON_ARROW = "🔛"
SOON_ARROW = "🔜"
TOP_ARROW = "🔝"
PLACE_OF_WORSHIP = "🛐"
ATOM_SYMBOL = "⚛"
OM = "🕉"
STAR_OF_DAVID = "✡"
WHEEL_OF_DHARMA = "☸"
YIN_YANG = "☯"
LATIN_CROSS = "✝"
ORTHODOX_CROSS = "☦"
STAR_AND_CRESCENT = "☪"
PEACE_SYMBOL = "☮"
MENORAH = "🕎"
DOTTED_SIXPOINTED_STAR = "🔯"
ARIES = "♈"
TAURUS = "♉"
GEMINI = "♊"
CANCER = "♋"
LEO = "♌"
VIRGO = "♍"
LIBRA = "♎"
SCORPIO = "♏"
SAGITTARIUS = "♐"
CAPRICORN = "♑"
AQUARIUS = "♒"
PISCES = "♓"
OPHIUCHUS = "⛎"
SHUFFLE_TRACKS_BUTTON = "🔀"
REPEAT_BUTTON = "🔁"
REPEAT_SINGLE_BUTTON = "🔂"
PLAY_BUTTON = "▶"
FASTFORWARD_BUTTON = "⏩"
NEXT_TRACK_BUTTON = "⏭"
PLAY_OR_PAUSE_BUTTON = "⏯"
REVERSE_BUTTON = "◀"
FAST_REVERSE_BUTTON = "⏪"
LAST_TRACK_BUTTON = "⏮"
UPWARDS_BUTTON = "🔼"
FAST_UP_BUTTON = "⏫"
DOWNWARDS_BUTTON = "🔽"
FAST_DOWN_BUTTON = "⏬"
PAUSE_BUTTON = "⏸"
STOP_BUTTON = "⏹"
RECORD_BUTTON = "⏺"
EJECT_BUTTON = "⏏"
CINEMA = "🎦"
DIM_BUTTON = "🔅"
BRIGHT_BUTTON = "🔆"
ANTENNA_BARS = "📶"
VIBRATION_MODE = "📳"
MOBILE_PHONE_OFF = "📴"
FEMALE_SIGN = "♀"
MALE_SIGN = "♂"
MEDICAL_SYMBOL = "⚕"
INFINITY = "♾"
RECYCLING_SYMBOL = "♻"
FLEURDELIS = "⚜"
TRIDENT_EMBLEM = "🔱"
NAME_BADGE = "📛"
JAPANESE_SYMBOL_FOR_BEGINNER = "🔰"
HOLLOW_RED_CIRCLE = "⭕"
CHECK_MARK_BUTTON = "✅"
CHECK_BOX_WITH_CHECK = "☑"
CHECK_MARK = "✔"
MULTIPLICATION_SIGN = "✖"
CROSS_MARK = "❌"
CROSS_MARK_BUTTON = "❎"
PLUS_SIGN = "➕"
MINUS_SIGN = "➖"
DIVISION_SIGN = "➗"
CURLY_LOOP = "➰"
DOUBLE_CURLY_LOOP = "➿"
PART_ALTERNATION_MARK = "〽"
EIGHTSPOKED_ASTERISK = "✳"
EIGHTPOINTED_STAR = "✴"
SPARKLE = "❇"
DOUBLE_EXCLAMATION_MARK = "‼"
EXCLAMATION_QUESTION_MARK = "⁉"
QUESTION_MARK = "❓"
WHITE_QUESTION_MARK = "❔"
WHITE_EXCLAMATION_MARK = "❕"
EXCLAMATION_MARK = "❗"
WAVY_DASH = "〰"
COPYRIGHT = "©"
REGISTERED = "®"
TRADE_MARK = "™"
KEYCAP_HASHTAG = "#️⃣"
KEYCAP_STAR = "*️⃣"
KEYCAP_0 = "0️⃣"
KEYCAP_1 = "1️⃣"
KEYCAP_2 = "2️⃣"
KEYCAP_3 = "3️⃣"
KEYCAP_4 = "4️⃣"
KEYCAP_5 = "5️⃣"
KEYCAP_6 = "6️⃣"
KEYCAP_7 = "7️⃣"
KEYCAP_8 = "8️⃣"
KEYCAP_9 = "9️⃣"
KEYCAP_10 = "🔟"
INPUT_LATIN_UPPERCASE = "🔠"
INPUT_LATIN_LOWERCASE = "🔡"
INPUT_NUMBERS = "🔢"
INPUT_SYMBOLS = "🔣"
INPUT_LATIN_LETTERS = "🔤"
A_BUTTON_BLOOD_TYPE = "🅰"
AB_BUTTON_BLOOD_TYPE = "🆎"
B_BUTTON_BLOOD_TYPE = "🅱"
CL_BUTTON = "🆑"
COOL_BUTTON = "🆒"
FREE_BUTTON = "🆓"
INFORMATION = "ℹ"
ID_BUTTON = "🆔"
CIRCLED_M = "Ⓜ"
NEW_BUTTON = "🆕"
NG_BUTTON = "🆖"
O_BUTTON_BLOOD_TYPE = "🅾"
OK_BUTTON = "🆗"
P_BUTTON = "🅿"
SOS_BUTTON = "🆘"
UP_BUTTON = "🆙"
VS_BUTTON = "🆚"
JAPANESE_HERE_BUTTON = "🈁"
JAPANESE_SERVICE_CHARGE_BUTTON = "🈂"
JAPANESE_MONTHLY_AMOUNT_BUTTON = "🈷"
JAPANESE_NOT_FREE_OF_CHARGE_BUTTON = "🈶"
JAPANESE_RESERVED_BUTTON = "🈯"
JAPANESE_BARGAIN_BUTTON = "🉐"
JAPANESE_DISCOUNT_BUTTON = "🈹"
JAPANESE_FREE_OF_CHARGE_BUTTON = "🈚"
JAPANESE_PROHIBITED_BUTTON = "🈲"
JAPANESE_ACCEPTABLE_BUTTON = "🉑"
JAPANESE_APPLICATION_BUTTON = "🈸"
JAPANESE_PASSING_GRADE_BUTTON = "🈴"
JAPANESE_VACANCY_BUTTON = "🈳"
JAPANESE_CONGRATULATIONS_BUTTON = "㊗"
JAPANESE_SECRET_BUTTON = "㊙"
JAPANESE_OPEN_FOR_BUSINESS_BUTTON = "🈺"
JAPANESE_NO_VACANCY_BUTTON = "🈵"
RED_CIRCLE = "🔴"
ORANGE_CIRCLE = "🟠"
YELLOW_CIRCLE = "🟡"
GREEN_CIRCLE = "🟢"
BLUE_CIRCLE = "🔵"
PURPLE_CIRCLE = "🟣"
BROWN_CIRCLE = "🟤"
BLACK_CIRCLE = "⚫"
WHITE_CIRCLE = "⚪"
RED_SQUARE = "🟥"
ORANGE_SQUARE = "🟧"
YELLOW_SQUARE = "🟨"
GREEN_SQUARE = "🟩"
BLUE_SQUARE = "🟦"
PURPLE_SQUARE = "🟪"
BROWN_SQUARE = "🟫"
BLACK_LARGE_SQUARE = "⬛"
WHITE_LARGE_SQUARE = "⬜"
BLACK_MEDIUM_SQUARE = "◼"
WHITE_MEDIUM_SQUARE = "◻"
BLACK_MEDIUMSMALL_SQUARE = "◾"
WHITE_MEDIUMSMALL_SQUARE = "◽"
BLACK_SMALL_SQUARE = "▪"
WHITE_SMALL_SQUARE = "▫"
LARGE_ORANGE_DIAMOND = "🔶"
LARGE_BLUE_DIAMOND = "🔷"
SMALL_ORANGE_DIAMOND = "🔸"
SMALL_BLUE_DIAMOND = "🔹"
RED_TRIANGLE_POINTED_UP = "🔺"
RED_TRIANGLE_POINTED_DOWN = "🔻"
DIAMOND_WITH_A_DOT = "💠"
RADIO_BUTTON = "🔘"
WHITE_SQUARE_BUTTON = "🔳"
BLACK_SQUARE_BUTTON = "🔲"
CHEQUERED_FLAG = "🏁"
TRIANGULAR_FLAG = "🚩"
CROSSED_FLAGS = "🎌"
BLACK_FLAG = "🏴"
WHITE_FLAG = "🏳"
RAINBOW_FLAG = "🏳️‍🌈"
PIRATE_FLAG = "🏴‍☠️"
FLAG_ASCENSION_ISLAND = "🇦🇨"
FLAG_ANDORRA = "🇦🇩"
FLAG_UNITED_ARAB_EMIRATES = "🇦🇪"
FLAG_AFGHANISTAN = "🇦🇫"
FLAG_ANTIGUA_BARBUDA = "🇦🇬"
FLAG_ANGUILLA = "🇦🇮"
FLAG_ALBANIA = "🇦🇱"
FLAG_ARMENIA = "🇦🇲"
FLAG_ANGOLA = "🇦🇴"
FLAG_ANTARCTICA = "🇦🇶"
FLAG_ARGENTINA = "🇦🇷"
FLAG_AMERICAN_SAMOA = "🇦🇸"
FLAG_AUSTRIA = "🇦🇹"
FLAG_AUSTRALIA = "🇦🇺"
FLAG_ARUBA = "🇦🇼"
FLAG_ÅLAND_ISLANDS = "🇦🇽"
FLAG_AZERBAIJAN = "🇦🇿"
FLAG_BOSNIA_HERZEGOVINA = "🇧🇦"
FLAG_BARBADOS = "🇧🇧"
FLAG_BANGLADESH = "🇧🇩"
FLAG_BELGIUM = "🇧🇪"
FLAG_BURKINA_FASO = "🇧🇫"
FLAG_BULGARIA = "🇧🇬"
FLAG_BAHRAIN = "🇧🇭"
FLAG_BURUNDI = "🇧🇮"
FLAG_BENIN = "🇧🇯"
FLAG_ST_BARTHÉLEMY = "🇧🇱"
FLAG_BERMUDA = "🇧🇲"
FLAG_BRUNEI = "🇧🇳"
FLAG_BOLIVIA = "🇧🇴"
FLAG_CARIBBEAN_NETHERLANDS = "🇧🇶"
FLAG_BRAZIL = "🇧🇷"
FLAG_BAHAMAS = "🇧🇸"
FLAG_BHUTAN = "🇧🇹"
FLAG_BOUVET_ISLAND = "🇧🇻"
FLAG_BOTSWANA = "🇧🇼"
FLAG_BELARUS = "🇧🇾"
FLAG_BELIZE = "🇧🇿"
FLAG_CANADA = "🇨🇦"
FLAG_COCOS_KEELING_ISLANDS = "🇨🇨"
FLAG_CONGO_KINSHASA = "🇨🇩"
FLAG_CENTRAL_AFRICAN_REPUBLIC = "🇨🇫"
FLAG_CONGO_BRAZZAVILLE = "🇨🇬"
FLAG_SWITZERLAND = "🇨🇭"
FLAG_CÔTE_DIVOIRE = "🇨🇮"
FLAG_COOK_ISLANDS = "🇨🇰"
FLAG_CHILE = "🇨🇱"
FLAG_CAMEROON = "🇨🇲"
FLAG_CHINA = "🇨🇳"
FLAG_COLOMBIA = "🇨🇴"
FLAG_CLIPPERTON_ISLAND = "🇨🇵"
FLAG_COSTA_RICA = "🇨🇷"
FLAG_CUBA = "🇨🇺"
FLAG_CAPE_VERDE = "🇨🇻"
FLAG_CURAÇAO = "🇨🇼"
FLAG_CHRISTMAS_ISLAND = "🇨🇽"
FLAG_CYPRUS = "🇨🇾"
FLAG_CZECHIA = "🇨🇿"
FLAG_GERMANY = "🇩🇪"
FLAG_DIEGO_GARCIA = "🇩🇬"
FLAG_DJIBOUTI = "🇩🇯"
FLAG_DENMARK = "🇩🇰"
FLAG_DOMINICA = "🇩🇲"
FLAG_DOMINICAN_REPUBLIC = "🇩🇴"
FLAG_ALGERIA = "🇩🇿"
FLAG_CEUTA_MELILLA = "🇪🇦"
FLAG_ECUADOR = "🇪🇨"
FLAG_ESTONIA = "🇪🇪"
FLAG_EGYPT = "🇪🇬"
FLAG_WESTERN_SAHARA = "🇪🇭"
FLAG_ERITREA = "🇪🇷"
FLAG_SPAIN = "🇪🇸"
FLAG_ETHIOPIA = "🇪🇹"
FLAG_EUROPEAN_UNION = "🇪🇺"
FLAG_FINLAND = "🇫🇮"
FLAG_FIJI = "🇫🇯"
FLAG_FALKLAND_ISLANDS = "🇫🇰"
FLAG_MICRONESIA = "🇫🇲"
FLAG_FAROE_ISLANDS = "🇫🇴"
FLAG_FRANCE = "🇫🇷"
FLAG_GABON = "🇬🇦"
FLAG_UNITED_KINGDOM = "🇬🇧"
FLAG_GRENADA = "🇬🇩"
FLAG_GEORGIA = "🇬🇪"
FLAG_FRENCH_GUIANA = "🇬🇫"
FLAG_GUERNSEY = "🇬🇬"
FLAG_GHANA = "🇬🇭"
FLAG_GIBRALTAR = "🇬🇮"
FLAG_GREENLAND = "🇬🇱"
FLAG_GAMBIA = "🇬🇲"
FLAG_GUINEA = "🇬🇳"
FLAG_GUADELOUPE = "🇬🇵"
FLAG_EQUATORIAL_GUINEA = "🇬🇶"
FLAG_GREECE = "🇬🇷"
FLAG_SOUTH_GEORGIA_SOUTH_SANDWICH_ISLANDS = "🇬🇸"
FLAG_GUATEMALA = "🇬🇹"
FLAG_GUAM = "🇬🇺"
FLAG_GUINEABISSAU = "🇬🇼"
FLAG_GUYANA = "🇬🇾"
FLAG_HONG_KONG_SAR_CHINA = "🇭🇰"
FLAG_HEARD_MCDONALD_ISLANDS = "🇭🇲"
FLAG_HONDURAS = "🇭🇳"
FLAG_CROATIA = "🇭🇷"
FLAG_HAITI = "🇭🇹"
FLAG_HUNGARY = "🇭🇺"
FLAG_CANARY_ISLANDS = "🇮🇨"
FLAG_INDONESIA = "🇮🇩"
FLAG_IRELAND = "🇮🇪"
FLAG_ISRAEL = "🇮🇱"
FLAG_ISLE_OF_MAN = "🇮🇲"
FLAG_INDIA = "🇮🇳"
FLAG_BRITISH_INDIAN_OCEAN_TERRITORY = "🇮🇴"
FLAG_IRAQ = "🇮🇶"
FLAG_IRAN = "🇮🇷"
FLAG_ICELAND = "🇮🇸"
FLAG_ITALY = "🇮🇹"
FLAG_JERSEY = "🇯🇪"
FLAG_JAMAICA = "🇯🇲"
FLAG_JORDAN = "🇯🇴"
FLAG_JAPAN = "🇯🇵"
FLAG_KENYA = "🇰🇪"
FLAG_KYRGYZSTAN = "🇰🇬"
FLAG_CAMBODIA = "🇰🇭"
FLAG_KIRIBATI = "🇰🇮"
FLAG_COMOROS = "🇰🇲"
FLAG_ST_KITTS_NEVIS = "🇰🇳"
FLAG_NORTH_KOREA = "🇰🇵"
FLAG_SOUTH_KOREA = "🇰🇷"
FLAG_KUWAIT = "🇰🇼"
FLAG_CAYMAN_ISLANDS = "🇰🇾"
FLAG_KAZAKHSTAN = "🇰🇿"
FLAG_LAOS = "🇱🇦"
FLAG_LEBANON = "🇱🇧"
FLAG_ST_LUCIA = "🇱🇨"
FLAG_LIECHTENSTEIN = "🇱🇮"
FLAG_SRI_LANKA = "🇱🇰"
FLAG_LIBERIA = "🇱🇷"
FLAG_LESOTHO = "🇱🇸"
FLAG_LITHUANIA = "🇱🇹"
FLAG_LUXEMBOURG = "🇱🇺"
FLAG_LATVIA = "🇱🇻"
FLAG_LIBYA = "🇱🇾"
FLAG_MOROCCO = "🇲🇦"
FLAG_MONACO = "🇲🇨"
FLAG_MOLDOVA = "🇲🇩"
FLAG_MONTENEGRO = "🇲🇪"
FLAG_ST_MARTIN = "🇲🇫"
FLAG_MADAGASCAR = "🇲🇬"
FLAG_MARSHALL_ISLANDS = "🇲🇭"
FLAG_NORTH_MACEDONIA = "🇲🇰"
FLAG_MALI = "🇲🇱"
FLAG_MYANMAR_BURMA = "🇲🇲"
FLAG_MONGOLIA = "🇲🇳"
FLAG_MACAO_SAR_CHINA = "🇲🇴"
FLAG_NORTHERN_MARIANA_ISLANDS = "🇲🇵"
FLAG_MARTINIQUE = "🇲🇶"
FLAG_MAURITANIA = "🇲🇷"
FLAG_MONTSERRAT = "🇲🇸"
FLAG_MALTA = "🇲🇹"
FLAG_MAURITIUS = "🇲🇺"
FLAG_MALDIVES = "🇲🇻"
FLAG_MALAWI = "🇲🇼"
FLAG_MEXICO = "🇲🇽"
FLAG_MALAYSIA = "🇲🇾"
FLAG_MOZAMBIQUE = "🇲🇿"
FLAG_NAMIBIA = "🇳🇦"
FLAG_NEW_CALEDONIA = "🇳🇨"
FLAG_NIGER = "🇳🇪"
FLAG_NORFOLK_ISLAND = "🇳🇫"
FLAG_NIGERIA = "🇳🇬"
FLAG_NICARAGUA = "🇳🇮"
FLAG_NETHERLANDS = "🇳🇱"
FLAG_NORWAY = "🇳🇴"
FLAG_NEPAL = "🇳🇵"
FLAG_NAURU = "🇳🇷"
FLAG_NIUE = "🇳🇺"
FLAG_NEW_ZEALAND = "🇳🇿"
FLAG_OMAN = "🇴🇲"
FLAG_PANAMA = "🇵🇦"
FLAG_PERU = "🇵🇪"
FLAG_FRENCH_POLYNESIA = "🇵🇫"
FLAG_PAPUA_NEW_GUINEA = "🇵🇬"
FLAG_PHILIPPINES = "🇵🇭"
FLAG_PAKISTAN = "🇵🇰"
FLAG_POLAND = "🇵🇱"
FLAG_ST_PIERRE_MIQUELON = "🇵🇲"
FLAG_PITCAIRN_ISLANDS = "🇵🇳"
FLAG_PUERTO_RICO = "🇵🇷"
FLAG_PALESTINIAN_TERRITORIES = "🇵🇸"
FLAG_PORTUGAL = "🇵🇹"
FLAG_PALAU = "🇵🇼"
FLAG_PARAGUAY = "🇵🇾"
FLAG_QATAR = "🇶🇦"
FLAG_RÉUNION = "🇷🇪"
FLAG_ROMANIA = "🇷🇴"
FLAG_SERBIA = "🇷🇸"
FLAG_RUSSIA = "🇷🇺"
FLAG_RWANDA = "🇷🇼"
FLAG_SAUDI_ARABIA = "🇸🇦"
FLAG_SOLOMON_ISLANDS = "🇸🇧"
FLAG_SEYCHELLES = "🇸🇨"
FLAG_SUDAN = "🇸🇩"
FLAG_SWEDEN = "🇸🇪"
FLAG_SINGAPORE = "🇸🇬"
FLAG_ST_HELENA = "🇸🇭"
FLAG_SLOVENIA = "🇸🇮"
FLAG_SVALBARD_JAN_MAYEN = "🇸🇯"
FLAG_SLOVAKIA = "🇸🇰"
FLAG_SIERRA_LEONE = "🇸🇱"
FLAG_SAN_MARINO = "🇸🇲"
FLAG_SENEGAL = "🇸🇳"
FLAG_SOMALIA = "🇸🇴"
FLAG_SURINAME = "🇸🇷"
FLAG_SOUTH_SUDAN = "🇸🇸"
FLAG_SÃO_TOMÉ_PRÍNCIPE = "🇸🇹"
FLAG_EL_SALVADOR = "🇸🇻"
FLAG_SINT_MAARTEN = "🇸🇽"
FLAG_SYRIA = "🇸🇾"
FLAG_ESWATINI = "🇸🇿"
FLAG_TRISTAN_DA_CUNHA = "🇹🇦"
FLAG_TURKS_CAICOS_ISLANDS = "🇹🇨"
FLAG_CHAD = "🇹🇩"
FLAG_FRENCH_SOUTHERN_TERRITORIES = "🇹🇫"
FLAG_TOGO = "🇹🇬"
FLAG_THAILAND = "🇹🇭"
FLAG_TAJIKISTAN = "🇹🇯"
FLAG_TOKELAU = "🇹🇰"
FLAG_TIMORLESTE = "🇹🇱"
FLAG_TURKMENISTAN = "🇹🇲"
FLAG_TUNISIA = "🇹🇳"
FLAG_TONGA = "🇹🇴"
FLAG_TURKEY = "🇹🇷"
FLAG_TRINIDAD_TOBAGO = "🇹🇹"
FLAG_TUVALU = "🇹🇻"
FLAG_TAIWAN = "🇹🇼"
FLAG_TANZANIA = "🇹🇿"
FLAG_UKRAINE = "🇺🇦"
FLAG_UGANDA = "🇺🇬"
FLAG_US_OUTLYING_ISLANDS = "🇺🇲"
FLAG_UNITED_NATIONS = "🇺🇳"
FLAG_UNITED_STATES = "🇺🇸"
FLAG_URUGUAY = "🇺🇾"
FLAG_UZBEKISTAN = "🇺🇿"
FLAG_VATICAN_CITY = "🇻🇦"
FLAG_ST_VINCENT_GRENADINES = "🇻🇨"
FLAG_VENEZUELA = "🇻🇪"
FLAG_BRITISH_VIRGIN_ISLANDS = "🇻🇬"
FLAG_US_VIRGIN_ISLANDS = "🇻🇮"
FLAG_VIETNAM = "🇻🇳"
FLAG_VANUATU = "🇻🇺"
FLAG_WALLIS_FUTUNA = "🇼🇫"
FLAG_SAMOA = "🇼🇸"
FLAG_KOSOVO = "🇽🇰"
FLAG_YEMEN = "🇾🇪"
FLAG_MAYOTTE = "🇾🇹"
FLAG_SOUTH_AFRICA = "🇿🇦"
FLAG_ZAMBIA = "🇿🇲"
FLAG_ZIMBABWE = "🇿🇼"
FLAG_ENGLAND = "🏴󠁧󠁢󠁥󠁮󠁧󠁿"
FLAG_SCOTLAND = "🏴󠁧󠁢󠁳󠁣󠁴󠁿"
FLAG_WALES = "🏴󠁧󠁢󠁷󠁬󠁳󠁿"



# from __future__ import annotations
# from botovod import dbdrivers
# from botovod.agents import Agent, Chat
# from botovod.extensions.djangoapp.botovod import models
# import json
# from json import JSONDecodeError
# import logging


# class DBDriver(dbdrivers.DBDriver):
#     @classmethod
#     def connect(cls, **settings):
#         pass
    
#     @classmethod
#     def get_follower(cls, agent: Agent, chat: Chat) -> models.Follower:
#         try:
#             obj = models.Follower.objects.get(bot__name=agent.name, chat=chat.id)
#         except models.Follower.DoesNotExist:
#             return None
#         return Follower(obj)
    
#     @classmethod
#     def add_follower(cls, agent, chat):
#         bot = models.Bot.objects.get(name=agent.name)
#         obj = models.Follower(
#             chat=chat.id,
#             bot=bot,
#         )
#         obj.save()
#         return Follower(obj)
    
#     @classmethod
#     def delete_follower(cls, agent, chat):
#         follower = models.Follower.objects.get(agent=agent.__class__.__name__, chat=chat.id)
#         follower.delete()


# class Follower(dbdrivers.Follower):
#     def __init__(self, obj):
#         self.obj = obj

#     def get_chat(self):
#         return Chat(self.obj.bot.agent, self.obj.chat)

#     def get_dialog_name(self):
#         return self.obj.dialog

#     def set_dialog_name(self, name):
#         self.obj.dialog = name
#         self.obj.save()

#     def get_next_step(self):
#         return self.obj.next_step

#     def set_next_step(self, next_step):
#         self.obj.next_step = next_step
#         self.obj.save()

#     def get_history(self, after_date=None, before_date=None, input=None, text=None):
#         messages = models.Message.objects.filter(follower=self.obj)
#         if not after_date is None:
#             messages = messages.filter(date__gt=after_date)
#         if not before_date is None:
#             messages = messages.filter(date__lt=before_date)
#         if not input is None:
#             messages = messages.filter(input=input)
#         if not text is None:
#             messages = messages.filter(text__iregex=text)
#         return [message.to_object() for message in messages]

#     def add_history(self, message, input=True):
#         message = models.Message(
#             follower = self.obj,
#             input = input,
#             text = message.text,
#             images = json.loads([models.attachment_render(image) for image in message.images]),
#             audios = json.loads([models.attachment_render(audio) for audio in message.audios]),
#             videos = json.loads([models.attachment_render(video) for video in message.videos]),
#             documents = json.loads([
#                 models.attachment_render(document) for document in message.documents
#             ]),
#             locations = json.loads([
#                 models.location_render(location) for location in message.locations
#             ]),
#             raw = json.loads(message.raw),
#             date = message.date,
#         )
#         message.save()

#     def clear_history(self, after_date=None, before_date=None, input=None, text=None):
#         messages = models.Message.objects.filter(follower=self.obj)
#         if not after_date is None:
#             messages = messages.filter(date__gt=after_date)
#         if not before_date is None:
#             messages = messages.filter(date__lt=before_date)
#         if not input is None:
#             messages = messages.filter(input=input)
#         messages.delete()

#     def get_value(self, name):
#         try:
#             return json.loads(self.obj.data)[name]
#         except KeyError:
#             logging.warning("Value '%s' doesn't exist for follower %s %s", name,
#                             self.obj.bot.agent, self.obj.chat)
#         except JSONDecodeError:
#             logging.error("Cannot get value '%s' for follower %s %s - incorrect json",
#                           name, self.obj.bot.agent, self.obj.chat)

#     def set_value(self, name, value):
#         try:
#             data = json.loads(self.obj.data)
#         except JSONDecodeError:
#             logging.error("Incorrect json structure for follower %s %s",
#                             self.obj.bot.agent, self.obj.chat)
#             data = dict()
#         data[name] = value
#         self.obj.data = json.dumps(data)
#         self.obj.save()

#     def delete_value(self, name):
#         data = json.loads(self.obj.data)
#         try:
#             del data[name]
#         except KeyError:
#             logging.warning("Cannot delete value '%s' for follower %s %s - doesn't exist",
#                             name, self.obj.bot.agent, self.obj.chat)
#         self.obj.data = json.dumps(data)
#         self.obj.save()



import json
from botovod.agents import Agent, Attachment, Chat, Keyboard, Location, Message
from botovod.agents.telegram import TelegramAgent, TelegramCallback
from botovod.dbdrivers import Follower
from botovod.utils.exceptions import NotPassed
import logging
from typing import Any, Callable, Iterator


logger = logging.getLogger(__name__)


class Dialog:
    def __init__(self, agent: Agent, chat: Chat, message: Message, follower: Follower):
        self.agent = agent
        self.chat = chat
        self.message = message
        self.follower = follower

    def __new__(cls, agent: Agent, chat: Chat, message: Message, follower: Follower):
        dialog = super().__new__(cls)
        dialog.__init__(agent=agent, chat=chat, message=message, follower=follower)

        dialog_name = dialog.follower.get_dialog()
        if dialog_name is not None and dialog_name != cls.__name__:
            raise NotPassed

        if dialog_name is None:
            dialog.follower.set_dialog(cls.__name__)
        next_step = dialog.follower.get_next_step()
        logger.info("[%s:%s] Follower: %s; dialog: %s; step: %s", agent, agent.name,
                    dialog.follower.chat, cls, next_step)
        if next_step:
            getattr(dialog, next_step)()
        else:
            return dialog.start()

    def reply(self, text: (str, None)=None, images: Iterator[Attachment]=[],
              audios: Iterator[Attachment]=[], documents: Iterator[Attachment]=[],
              videos: Iterator[Attachment]=[], locations: Iterator[Location]=[],
              keyboard: (Keyboard, None)=None, **raw):
        self.agent.send_message(self.chat, text=text, images=images, audios=audios,
                                documents=documents, videos=videos, locations=locations,
                                keyboard=keyboard, **raw)

    def set_next_step(self, function: Callable):
        if hasattr(function, "__self__"):
            self.follower.set_dialog(function.__self__.__class__.__name__)
        else:
            self.follower.set_dialog(function.__qualname__.split(".")[-2])
        self.follower.set_next_step(function.__name__)

    def start_dialog(self, dialog_class: Callable):
        self.follower.set_dialog(dialog_class.__name__)
        dialog_class(self.agent, self.chat, self.message, self.follower)

    def start(self):
        raise NotImplementedError


class AsyncDialog:
    async def __init__(self, agent: Agent, chat: Chat, message: Message, follower: Follower):
        self.agent = agent
        self.chat = chat
        self.message = message
        self.follower = follower

    async def __new__(cls, agent: Agent, chat: Chat, message: Message, follower: Follower):
        dialog = super().__new__(cls)
        await dialog.__init__(agent=agent, chat=chat, message=message, follower=follower)

        dialog_name = await dialog.follower.a_get_dialog()
        if dialog_name is not None and dialog_name != cls.__name__:
            raise NotPassed
        
        next_step = "start"
        if dialog_name is None:
            await dialog.follower.a_set_dialog(cls.__name__)
        else:
            next_step = await dialog.follower.a_get_next_step()
        logger.info("[%s:%s] Follower: %s; dialog: %s; step: %s", agent, agent.name,
                    dialog.follower.chat, cls, next_step)
        if next_step:
            await getattr(dialog, next_step)()
        else:
            return await dialog.start()

    async def reply(self, text: (str, None)=None, images: Iterator[Attachment]=[],
                    audios: Iterator[Attachment]=[], documents: Iterator[Attachment]=[],
                    videos: Iterator[Attachment]=[], locations: Iterator[Location]=[],
                    keyboard: (Keyboard, None)=None, **raw):
        return await self.agent.a_send_message(chat=self.chat, text=text, images=images,
                                               audios=audios, documents=documents, videos=videos,
                                               locations=locations, keyboard=keyboard, **raw)

    async def set_next_step(self, function: Callable):
        if hasattr(function, "__self__"):
            await self.follower.a_set_dialog(function.__self__.__class__.__name__)
        else:
            await self.follower.a_set_dialog(function.__qualname__.split(".")[-2])
        await self.follower.a_set_next_step(function.__name__)

    async def start_dialog(self, dialog_class: Callable):
        await self.follower.a_set_dialog(dialog_class.__name__)
        await dialog_class(self.agent, self.chat, self.message, self.follower)

    async def start(self):
        raise NotImplementedError


# class MessagePaginator(Dialog):
#     @property
#     def prev_button(self) -> str:
#         raise NotImplementedError
    
#     @property
#     def next_button(self) -> str:
#         raise NotImplementedError


# class KeyboardPaginator(Dialog):
#     @property
#     def limit(self) -> int:
#         raise NotImplementedError
    
#     @property
#     def prev_button(self) -> str:
#         raise NotImplementedError
    
#     @property
#     def next_button(self) -> str:
#         raise NotImplementedError

#     def start(self):
#         self.follower.set_value("page", 0)
#         data = self.get_all_data()
#         if not data:
#             self.action_no_data()
#             return
        
#         page_data = data[:self.limit]
#         message = self.render(page_data)
#         buttons = []
#         if not message.keyboard is None:
#             buttons.extend(message.keyboard.buttons)
#         if self.limit < len(data):
#             buttons.append(self.next_button)
#         message.keyboard = Keyboard(*buttons)
#         self.reply(message)

#         self.follower.set_next_step("handle")

#     def handle(self):
#         page = self.follower.get_value("page")
#         if page is None:
#             page = 0
#         data = self.get_all_data()
#         if not data:
#             self.action_no_data()
#             return
        
#         if self.message.text == self.next_button:
#             if page*self.limit < len(data): 
#                 page += 1
#         elif self.message.text == self.prev_button:
#             if page > 0:
#                 page -= 1
#         else:
#             page_data = data[page*self.limit:(page+1)*self.limit]
#             self.action(page_data)
#             return

#         page_data = data[page*self.limit:(page+1)*self.limit]
#         message = self.render(page_data)
#         buttons = []
#         if not message.keyboard is None:
#             buttons.extend(message.keyboards.buttons)
#         if page > 0:
#             buttons.append(self.prev_button)
#         if (page+1)*self.limit < len(data):
#             buttons.append(self.next_button)
#         message.keyboard = Keyboard(*buttons)

#         self.agent.send_message(self.chat, message)
#         self.follower.set_value("page", page)

#     def get_all_data(self):
#         raise NotImplementedError

#     def render(self):
#         raise NotImplementedError

#     @classmethod
#     def action(cls):
#         raise NotImplementedError

#     @classmethod
#     def action_no_data(cls):
#         raise NotImplementedError



from botovod.agents import Agent, Chat, Message
from botovod.agents.telegram import TelegramAgent, TelegramCallback
from botovod.dbdrivers import Follower
from botovod.dialogs import AsyncDialog, Dialog
from botovod.utils.exceptions import NotPassed
from functools import wraps
import re
from typing import Callable


def to_text(is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if message.text is None:
                raise NotPassed
            return func(agent, chat, message.text, follower, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if self.message.text is None:
                raise NotPassed
            return func(self, self.message.text, *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def to_attachments(is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            attachments = []
            attachments.extend(message.images)
            attachments.extend(message.audios)
            attachments.extend(message.videos)
            attachments.extend(message.documents)
            if not attachments:
                raise NotPassed
            return func(agent, chat, attachments, follower, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            attachments = []
            attachments.extend(self.message.images)
            attachments.extend(self.message.audios)
            attachments.extend(self.message.videos)
            attachments.extend(self.message.documents)
            if not attachments:
                raise NotPassed
            return func(self, attachments, *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def to_images(is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if not message.images:
                raise NotPassed
            return func(agent, chat, message.images, follower, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if not self.message.images:
                raise NotPassed
            return func(self, self.message.images, *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def to_audios(is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if not message.audios:
                raise NotPassed
            return func(agent, chat, message.audios, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if not self.message.audios:
                raise NotPassed
            return func(self, self.message.audios, *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def to_videos(is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if not message.videos:
                raise NotPassed
            return func(agent, chat, message.videos, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if not self.message.videos:
                raise NotPassed
            return func(self, self.message.videos, *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def to_documents(is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if not message.documents:
                raise NotPassed
            return func(agent, chat, message.documents, follower, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if not self.message.documents:
                raise NotPassed
            return func(self, self.message.documents, *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def to_locations(is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if not message.locations:
                raise NotPassed
            return func(agent, chat, message.locations, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if not self.message.locations:
                raise NotPassed
            return func(self, self.message.locations, *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def only_regexp(expression: str, is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if message.text is None:
                raise NotPassed
            match = re.match(expression, message.text)
            if not match:
                raise NotPassed
            return func(agent, chat, *match.groups(), follower, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if self.message.text is None:
                raise NotPassed
            match = re.match(expression, self.message.text)
            if not match:
                raise NotPassed
            return func(self, *match.groups(), *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def only_agent(name: str, is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if agent.name != name:
                raise NotPassed
            return func(agent, chat, message, follower, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if self.agent.name != name:
                raise NotPassed
            return func(self, *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def only_chat(chat: Chat, cls: Agent=Agent, is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if not issubclass(agent, cls):
                raise NotPassed
            if message.chat.id != chat:
                raise NotPassed
            return func(agent, chat, message, follower, *args, **kwargs)

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if not issubclass(self.agent, cls):
                raise NotPassed
            if self.message.chat.id != chat:
                raise NotPassed
            return func(self, *args, **kwargs)

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def only_telegram_callback(is_dialog: bool=False):
    def decorator(func: Callable):
        @wraps(func)
        def func_wrapper(agent: Agent, chat: Chat, message: Message,
                         follower: (Follower, None)=None, *args, **kwargs):
            if isinstance(agent, TelegramAgent) and isinstance(message, TelegramCallback):
                return func(agent, chat, message, follower, **args, **kwargs)
            raise NotPassed

        @wraps(func)
        def dialog_wrapper(self, *args, **kwargs):
            if isinstance(self.agent, TelegramAgent) and isinstance(self.message, TelegramCallback):
                return func(self, self.message.text, *args, **kwargs)
            raise NotPassed

        return dialog_wrapper if is_dialog else func_wrapper

    return decorator


def start_dialog(dialog_cls: Dialog, agent: Agent, chat: Chat, message: Message,
                 follower: Follower):
    follower.set_dialog(dialog_cls.__name__)
    return dialog_cls(agent, chat, message, follower)


async def start_async_dialog(dialog_cls: AsyncDialog, agent: Agent, chat: Chat, message: Message,
                             follower: Follower):
    await follower.a_set_dialog(dialog_cls.__name__)
    return await dialog_cls(agent, chat, message, follower)



# from botovod import agents, Attachment, dbdrivers, Location, Message as BotoMessage
# from django.core.exceptions import ValidationError
# from django.db import models
# import json
# from json import JSONDecodeError


# def meta_validator(value):
#     try:
#         json.loads(value)
#     except JSONDecodeError:
#         raise ValidationError("Value is not json")


# class Follower(models.Model):
#     chat = models.CharField(max_length=64, blank=True)
#     bot = models.CharField(max_length=64)
#     dialog = models.CharField(max_length=64, null=True)
#     next_step = models.CharField(max_length=64, null=True)
#     data = models.TextField(blank=True, default="{}", validators=[meta_validator])

#     class Meta:
#         unique_together = ("chat", "bot")


# class Message(models.Model):
#     follower = models.ForeignKey(Follower, blank=True, on_delete=models.CASCADE)
#     input = models.BooleanField(blank=True)
#     text = models.TextField(null=True)
#     images = models.TextField(blank=True, default="[]", validators=[meta_validator])
#     audios = models.TextField(blank=True, default="[]", validators=[meta_validator])
#     videos = models.TextField(blank=True, default="[]", validators=[meta_validator])
#     documents = models.TextField(blank=True, default="[]", validators=[meta_validator])
#     locations = models.TextField(blank=True, default="[]", validators=[meta_validator])
#     raw = models.TextField(null=True, validators=[meta_validator])
#     date = models.DateTimeField(blank=True)

#     def to_object(self):
#         message = BotoMessage()
#         message.text = self.text
#         message.images = [attachment_parser(image) for image in json.loads(self.images)]
#         message.audios = [attachment_parser(audio) for audio in json.loads(self.audios)]
#         message.videos = [attachment_parser(video) for video in json.loads(self.videos)]
#         message.documents = [attachment_parser(document) for document in json.loads(self.documents)]
#         message.locations = [location_parser(location) for location in json.loads(self.locations)]
#         message.raw = json.loads(self.raw)
#         return message


# def attachment_render(attachment):
#     return {
#         "url": attachment.url,
#         "file": attachment.file,
#         "raw": attachment.raw,
#     }


# def attachment_parser(data):
#     attachment = Attachment
#     attachment.url = data["url"]
#     attachment.file = data["file"]
#     attachment.raw = data["raw"]
#     return attachment


# def location_render(location):
#     return {
#         "longitude": location.longitude,
#         "latitude": location.latitude,
#         "raw": location.raw,
#     }


# def location_parser(data):
#     location = Location(
#         longitude = data["longitude"],
#         latitude = data["latitude"],
#     )
#     location.raw = data["raw"]
#     return location



from __future__ import annotations
import asyncio
from botovod.agents import Agent
from botovod.dbdrivers import DBDriver 
import logging
from typing import Dict, Tuple


class AgentDict(dict):
    def __init__(self, botovod: Botovod):
        self.botovod = botovod

    def __setitem__(self, key: str, value: Agent):
        if key in self:
            del self[key]
        value.botovod = self.botovod
        value.name = key

        self.botovod.logger.info("[%s:%s] Agent was added to Botovod.", value, key)
        return super().__setitem__(key, value)

    def __delitem__(self, key: str):
        self[key].botovod = None
        self[key].name = None

        self.botovod.logger.info("[%s:%s] Agent was removed from Botovod.", self[key], key)
        return super().__delitem__(key)


class Botovod:
    def __init__(self, dbdriver: (DBDriver, None)=None,
                 logger: logging.Logger=logging.getLogger(__name__)):
        self.dbdriver = dbdriver
        self.agents = AgentDict(self)
        self.handlers = []
        self.logger = logger
        self.dict = {}

        logger.info("Initialiaze Botovod.")

    def __setitem__(self, name: str, value):
        self.dict[name] = value

    def __getitem__(self, name: str):
        return self.dict[name]

    def start(self):
        for agent in self.agents.values():
            agent.start()

    async def a_start(self):
        for agent in self.agents.values():
            await agent.a_start()

    def stop(self):
        for agent in self.agents.values():
            agent.stop()

    async def a_stop(self):
        for agent in self.agents.values():
            await agent.a_stop()

    def listen(self, name: str, headers: Dict[str, str],
               body: str) -> (Tuple[int, Dict[str, str], str], None):
        if name is not None and name not in self.agents:
            self.logger.error("Botovod have no agent with name '%s'!", name)
            return
        return self.agents[name].listen(headers, body)

    async def a_listen(self, name: str, headers: Dict[str, str],
                       body: str) -> (Tuple[int, Dict[str, str], str], None):
        if name is not None and name not in self.agents:
            self.logger.error("Botovod have no agent with name '%s'!", name)
            return
        return await self.agents[name].a_listen(headers, body)
